pub struct Cacheaxi<'d> { /* private fields */ }Expand description
AXI cache driver.
Implementations
Sourceimpl<'d> Cacheaxi<'d>
impl<'d> Cacheaxi<'d>
Sourcepub fn new(_peri: Peri<'d, CACHEAXI>) -> Self
pub fn new(_peri: Peri<'d, CACHEAXI>) -> Self
Create a new CACHEAXI driver. The cache is left disabled; call Self::enable() to turn it on.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns whether the cache is currently enabled.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Invalidate the entire cache, blocking until the operation completes.
Sourcepub fn start_read_monitors(&mut self, monitor: ReadMonitor)
pub fn start_read_monitors(&mut self, monitor: ReadMonitor)
Start the given read-side performance counter(s).
Sourcepub fn stop_read_monitors(&mut self, monitor: ReadMonitor)
pub fn stop_read_monitors(&mut self, monitor: ReadMonitor)
Stop the given read-side performance counter(s).
Sourcepub fn reset_read_monitors(&mut self, monitor: ReadMonitor)
pub fn reset_read_monitors(&mut self, monitor: ReadMonitor)
Reset the given read-side performance counter(s) to zero.
Sourcepub fn start_write_monitors(&mut self, monitor: WriteMonitor)
pub fn start_write_monitors(&mut self, monitor: WriteMonitor)
Start the given write-side performance counter(s).
Sourcepub fn stop_write_monitors(&mut self, monitor: WriteMonitor)
pub fn stop_write_monitors(&mut self, monitor: WriteMonitor)
Stop the given write-side performance counter(s).
Sourcepub fn reset_write_monitors(&mut self, monitor: WriteMonitor)
pub fn reset_write_monitors(&mut self, monitor: WriteMonitor)
Reset the given write-side performance counter(s) to zero.
Sourcepub fn read_hit_count(&self) -> u32
pub fn read_hit_count(&self) -> u32
Current read-hit count.
Sourcepub fn read_miss_count(&self) -> u32
pub fn read_miss_count(&self) -> u32
Current read-miss count.
Sourcepub fn write_hit_count(&self) -> u32
pub fn write_hit_count(&self) -> u32
Current write-hit count.
Sourcepub fn write_miss_count(&self) -> u32
pub fn write_miss_count(&self) -> u32
Current write-miss count.
Sourcepub fn take_error(&mut self) -> bool
pub fn take_error(&mut self) -> bool
Returns true and clears the flag if a cache error has occurred since the last call.